@@ -1,6 +1,6 @@
 // info.h
 
-// Copyright (C) 2012-2015 by Werner Lemberg.
+// Copyright (C) 2012-2016 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -11,8 +11,8 @@
 // with the ttfautohint library.
 
 
-#ifndef __INFO_H__
-#define __INFO_H__
+#ifndef INFO_H_
+#define INFO_H_
 
 #include <ttfautohint.h>
 #include <stdbool.h> // for llrb.h
@@ -77,6 +77,6 @@ info_post(void* user);
 
 } // extern "C"
 
-#endif // __INFO_H__
+#endif // INFO_H_
 
 // end of info.h
