@@ -1,6 +1,6 @@
 // main.cpp
 
-// Copyright (C) 2011-2015 by Werner Lemberg.
+// Copyright (C) 2011-2016 by Werner Lemberg.
 //
 // This file is part of the ttfautohint library, and may only be used,
 // modified, and distributed under the terms given in `COPYING'.  By
@@ -72,7 +72,7 @@ typedef struct Tag_Names_
 // the available script tags and its descriptions are directly extracted
 // from `ttfautohint-scripts.h'
 #undef SCRIPT
-#define SCRIPT(s, S, d, h, sc1, sc2, sc3) \
+#define SCRIPT(s, S, d, h, H, ss) \
           {#s, d},
 
 const Tag_Names script_names[] =
@@ -501,7 +501,7 @@ show_version()
 #else
 "ttfautohint " VERSION "\n"
 #endif
-"Copyright (C) 2011-2015 Werner Lemberg <wl@gnu.org>.\n"
+"Copyright (C) 2011-2016 Werner Lemberg <wl@gnu.org>.\n"
 "License: FreeType License (FTL) or GNU GPLv2.\n"
 "This is free software: you are free to change and redistribute it.\n"
 "There is NO WARRANTY, to the extent permitted by law.\n");
