@@ -1,7 +1,7 @@
 /* tacontrol.c */
 
 /*
- * Copyright (C) 2014-2015 by Werner Lemberg.
+ * Copyright (C) 2014-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -13,7 +13,7 @@
  */
 
 #include "ta.h"
-#include "taharfbuzz.h"
+#include "tashaper.h"
 
 #include <locale.h>
 #include <limits.h>
@@ -674,7 +674,7 @@ TA_control_build_tree(FONT* font)
           s = control_show_line(font, &d);
           if (s)
           {
-            fprintf(stderr, "Control instruction %s ignored.\n", s);
+            fprintf(stderr, "Control instruction `%s' ignored.\n", s);
             sdsfree(s);
           }
 
