@@ -1,7 +1,7 @@
 /* tacontrol.h */
 
 /*
- * Copyright (C) 2014-2015 by Werner Lemberg.
+ * Copyright (C) 2014-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -13,8 +13,8 @@
  */
 
 
-#ifndef __TACONTROL_H__
-#define __TACONTROL_H__
+#ifndef TACONTROL_H_
+#define TACONTROL_H_
 
 #ifdef __cplusplus
 extern "C" {
@@ -352,6 +352,6 @@ TA_control_segment_dir_get_next(FONT* font,
 } /* extern "C" */
 #endif
 
-#endif /* __TACONTROL_H__ */
+#endif /* TACONTROL_H_ */
 
 /* end of control.h */
