@@ -1,7 +1,7 @@
 /* tagloadr.h */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -17,8 +17,8 @@
 
 /* heavily modified 2011 by Werner Lemberg <wl@gnu.org> */
 
-#ifndef __TAGLOADR_H__
-#define __TAGLOADR_H__
+#ifndef TAGLOADR_H_
+#define TAGLOADR_H_
 
 #include <ft2build.h>
 #include FT_FREETYPE_H
@@ -136,6 +136,6 @@ TA_GlyphLoader_CopyPoints(TA_GlyphLoader target,
 }
 #endif
 
-#endif /* __TAGLOADR_H__ */
+#endif /* TAGLOADR_H_ */
 
 /* end of tagloadr.h */
