@@ -1,7 +1,7 @@
 /* tahints.h */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -17,8 +17,8 @@
 
 /* heavily modified 2011 by Werner Lemberg <wl@gnu.org> */
 
-#ifndef __TAHINTS_H__
-#define __TAHINTS_H__
+#ifndef TAHINTS_H_
+#define TAHINTS_H_
 
 #include "tatypes.h"
 
@@ -353,6 +353,10 @@ typedef enum TA_Action_
   ta_adjust_bound_serif,
   ta_adjust_bound_round,
   ta_adjust_bound_round_serif,
+  ta_adjust_down_bound,
+  ta_adjust_down_bound_serif,
+  ta_adjust_down_bound_round,
+  ta_adjust_down_bound_round_serif,
 
   ta_link,
   ta_link_serif,
@@ -367,26 +371,42 @@ typedef enum TA_Action_
   ta_stem_bound_serif,
   ta_stem_bound_round,
   ta_stem_bound_round_serif,
+  ta_stem_down_bound,
+  ta_stem_down_bound_serif,
+  ta_stem_down_bound_round,
+  ta_stem_down_bound_round_serif,
 
   ta_serif,
   ta_serif_lower_bound,
   ta_serif_upper_bound,
   ta_serif_upper_lower_bound,
+  ta_serif_down_lower_bound,
+  ta_serif_down_upper_bound,
+  ta_serif_down_upper_lower_bound,
 
   ta_serif_anchor,
   ta_serif_anchor_lower_bound,
   ta_serif_anchor_upper_bound,
   ta_serif_anchor_upper_lower_bound,
+  ta_serif_anchor_down_lower_bound,
+  ta_serif_anchor_down_upper_bound,
+  ta_serif_anchor_down_upper_lower_bound,
 
   ta_serif_link1,
   ta_serif_link1_lower_bound,
   ta_serif_link1_upper_bound,
   ta_serif_link1_upper_lower_bound,
+  ta_serif_link1_down_lower_bound,
+  ta_serif_link1_down_upper_bound,
+  ta_serif_link1_down_upper_lower_bound,
 
   ta_serif_link2,
   ta_serif_link2_lower_bound,
   ta_serif_link2_upper_bound,
   ta_serif_link2_upper_lower_bound,
+  ta_serif_link2_down_lower_bound,
+  ta_serif_link2_down_upper_bound,
+  ta_serif_link2_down_upper_lower_bound,
 
   ta_bound
 } TA_Action;
@@ -497,6 +517,7 @@ FT_Error
 ta_axis_hints_new_edge(TA_AxisHints axis,
                        FT_Int fpos,
                        TA_Direction dir,
+                       FT_Bool top_to_bottom_hinting,
                        TA_Edge* edge);
 
 #ifdef TA_DEBUG
@@ -560,7 +581,7 @@ ta_glyph_hints_done(TA_GlyphHints hints);
 } /* extern "C" */
 #endif
 
-#endif /* __TAHINTS_H__ */
+#endif /* TAHINTS_H_ */
 
 
 /* end of tahints.h */
