@@ -1,7 +1,7 @@
 /* ttfautohint.c */
 
 /*
- * Copyright (C) 2011-2015 by Werner Lemberg.
+ * Copyright (C) 2011-2016 by Werner Lemberg.
  *
  * This file is part of the ttfautohint library, and may only be used,
  * modified, and distributed under the terms given in `COPYING'.  By
@@ -368,7 +368,7 @@ TTF_autohint(const char* options,
     if (*s)
     {
       /* we map numberset.h's error codes to values starting with 0x100 */
-      error = 0x100 - (FT_Error)x_height_snapping_exceptions;
+      error = 0x100 - (FT_Error)(uintptr_t)x_height_snapping_exceptions;
       errlinenum = 0;
       errline = (char*)x_height_snapping_exceptions_string;
       errpos = (char*)s;
